@@ -1,8 +1,8 @@
 from PDSUtilities.pandas.plot_histograms import plot_histograms
 from PDSUtilities.pandas.plot_parallel_categories import plot_parallel_categories
 from PDSUtilities.pandas.plot_parallel_coordinates import plot_parallel_coordinates
-from PDSUtilities.pandas.utilities import get_numerical_columns
-from PDSUtilities.pandas.utilities import get_categorical_columns
+from PDSUtilities.pandas.plot_parallel_coordinates import get_numerical_columns
+from PDSUtilities.pandas.plot_parallel_categories import get_categorical_columns
 from PDSUtilities.pandas.plot_correlation_scatter import plot_correlation_scatter
 from PDSUtilities.pandas.plot_correlation_matrix import plot_correlation_matrix
 from PDSUtilities.pandas.plot_correlation_triangle import plot_correlation_triangle
